#!/bin/ksh
# ******************************************************************************************************************************
# * Licensed Materials - Property of IBM                                                                                       *
# * (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
# *                                                                                                                            *
# *US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
# ******************************************************************************************************************************

rcrdone(){
db2 connect reset
db2 terminate
echo $MESSAGE:$EXITCODE
echo $CRREWECH002$
exit $EXITCODE
}

validate() {

if [ -z $CURINST ] 
then
	EXITCODE=$CRREW4501E
	MESSAGE=$CRREWMSGE001
	rcrdone
fi  

if [ -z $DBNAME ] 
then
	EXITCODE=$CRREW4502E
	MESSAGE=$CRREWMSGE002
	rcrdone
fi

if [ -z $DBUSER ] 
then
	EXITCODE=$CRREW4503E
	MESSAGE=$CRREWMSGE003
	rcrdone
fi

if [ -z $DBPASSWD ] 
then
	EXITCODE=$CRREW4504E
	MESSAGE=$CRREWMSGE004
	rcrdone
fi

if [ -z $DATA_HOME ] 
then
	EXITCODE=$CRREW4508E
	MESSAGE=$CRREWMSGE008
	rcrdone
fi

if [ -z $LANG ]
then
	EXITCODE=$CRREW4585E
	MESSAGE=$CRREWMSGE085
	rcrdone
fi

db2ilist>db2ilist.txt
grep -e $CURINST db2ilist.txt>/dev/null
if [ $? -eq 1 ]
then
	rm -f db2ilist.txt
	EXITCODE=$CRREW4501E
	MESSAGE=$CRREWMSGE001
	rcrdone
fi  

rm -f db2ilist.txt

db2 attach to  $CURINST user $DBUSER using  "$DBPASSWD"
if [ $? -ne 0 ] 
then
	EXITCODE=$CRREW4584E
	MESSAGE=$CRREWMSGE084
	rcrdone
fi  



rcrdone
}
chmod -R +x lang

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "en" ]
then 
     LOCALE="en"
	. lang/en/messages.sh
fi	

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "it" ]
then 
	LOCALE="it"
	. lang/it/messages.sh
fi	

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "pl" ]
then 
	LOCALE="pl"
	. lang/pl/messages.sh
fi	

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "ko" ]
then 
	LOCALE="kr"
	. lang/kr/messages.sh
fi

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "ja" ]
then 
	LOCALE="ja"
	. lang/ja/messages.sh
fi

if [ `echo $LANG | sed 's/\([a-z]*_[A-Z][A-Z]\).*/\1/'` == "zh_CN" ]
then 
	LOCALE="zh_CN"
	. lang/zh_CN/messages.sh
fi

if [ `echo $LANG | sed 's/\([a-z]*_[A-Z][A-Z]\).*/\1/'` == "zh_TW" ]
then 
	LOCALE="zh_TW"
	. lang/zh_TW/messages.sh
fi

if [ -z $LOCALE ]
then
	 LOCALE="en"
	. lang/en/messages.sh
fi	

SILENT=0
MESSAGE="No errors"
EXITCODE=0

DB2_CMD="db2 -tsf"

if [ $# -eq 1 ]
	then 
	if [ $1 == "-silent" ]
	then
			SILENT=1
	else 
			SILENT=0
	fi
	if [ $1 == "-debug" ]
	then
		DB2_CMD="db2 -tvsf"
		else 
			DB2_CMD="db2 -tsf"
	fi
fi

if [ $# -eq 1 ]
	then
	if [ $1 == "-validate" ]
		then
		   validate
	fi
fi	

if [ $# -eq 2 ]
then
	if [ $2 -eq "-debug" ]
	 then
			DB2_CMD="db2 -tvsf"
	else 
			DB2_CMD="db2 -tsf"
	fi
fi



if [ $SILENT -eq 0 ]
then 
	echo $CRREWECH001
fi	

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT002
	read DBNAME
fi

if [ -z $DBNAME ]
then
	MESSAGE=$CRREWMSGE002
	EXITCODE=$CRREW4502E
	rcrdone
fi


if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT003
	read DBUSER
fi

if [ -z $DBUSER ]
then
	MESSAGE=$CRREWMSGE003
	EXITCODE=$CRREW4503E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT004
	read DBPASSWD
fi

if [ -z $DBPASSWD ]
then
	MESSAGE=$CRREWMSGE004
	EXITCODE=$CRREW4504E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT008
	read DATA_HOME
fi

if [ -z $DATA_HOME ]
then
	MESSAGE=$CRREWMSGE008
	EXITCODE=$CRREW4508E
	rcrdone
fi

CD=`pwd`

if [ ! -d $CD/logs ]
then
	mkdir $CD/logs
else
	rm -dfr $CD/logs
	mkdir $CD/logs	
fi
if [ $? -ne 0 ]
then
	MESSAGE=$CRREWMSGE076
	EXITCODE=$CRREW4576E
	rcrdone
fi
CONNSTR="db2 CONNECT TO $DBNAME USER $DBUSER USING $DBPASSWD"

if [ $SILENT -eq 1 ]
then 
	$CONNSTR
	db2 "SELECT COUNT(*) FROM CMCAPACITY"
	if [ $? -eq 0 ]
	then
		rcrdone
	fi
fi	


db2 "CREATE DATABASE $DBNAME USING CODESET UTF-8 TERRITORY US"  > ./logs/createDB.log
grep -e "SQLSTATE" $CD/logs/createDB.log >/dev/null
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE013  
	EXITCODE=$CRREW4513E
	echo $CRREWECH003
	rcrdone
fi

$CONNSTR
db2 "create bufferpool CBP_32K  SIZE 1000 PAGESIZE 32768">./logs/bufferpool.log
db2 "create bufferpool CBP_4K  SIZE 1000 PAGESIZE 4096">>./logs/bufferpool.log

grep -e "SQLSTATE" $CD/logs/bufferpool.log >/dev/null

#if [ $? -eq 0 ]
#then
#	echo "Error creating bufferpools.  Please review $CD/logs/bufferpool.log for error messages"
#	rcrdone
#fi


DATA_HOME=$DATA_HOME/$DBNAME

db2 update db cfg for $DBNAME using APPLHEAPSZ 1024
db2 update db cfg for $DBNAME using LOCKTIMEOUT 240

db2 force applications all
db2stop force
db2start

$CONNSTR
$CONNSTR
db2 "CREATE TEMPORARY TABLESPACE CTEMPSPACE32K IN DATABASE PARTITION GROUP IBMTEMPGROUP PAGESIZE 32768 MANAGED BY SYSTEM USING ('$DATA_HOME/data1/tempspace32k') BUFFERPOOL CBP_32K " >./logs/tbspaces.log
db2 "CREATE USER TEMPORARY TABLESPACE USRTMP4K IN DATABASE PARTITION GROUP IBMDEFAULTGROUP PAGESIZE 4096 MANAGED BY AUTOMATIC STORAGE BUFFERPOOL CBP_4K" >>./logs/tbspaces.log
db2 "CREATE REGULAR TABLESPACE CTBS_4K IN DATABASE PARTITION GROUP IBMDEFAULTGROUP PAGESIZE 4096 MANAGED BY DATABASE USING (FILE '$DATA_HOME/data1/ctbs_4k.1' 10000) BUFFERPOOL CBP_4K AUTORESIZE YES INCREASESIZE 50 M MAXSIZE NONE DROPPED TABLE RECOVERY ON">>./logs/tbspaces.log
grep -e "SQLSTATE" $CD/logs/tbspaces.log >/dev/null

if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE015
	EXITCODE=$CRREW4515E
	echo $CRREWECH005
	rcrdone
fi

$CONNSTR
db2 -tvf cmstore.ddl>logs/cmstore.log
grep -e "SQLSTATE" $CD/logs/cmstore.log >/dev/null

if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE077
	EXITCODE=$CRREW4577E
	echo $CRREWECH022
	rcrdone
fi

cat db2move.lst_original|sed -e "s/\$CS_SCHEMA/`echo $DBUSER`/g" >move/db2move.lst
cd move
db2move $DBNAME import -l ./lobs
grep -e "SQLSTATE" IMPORT.out
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE027
	EXITCODE=$CRREW4527E
	cd ../
	rcrdone
fi
cd ../
$CONNSTR
db2 -tvf cmstore_trig.ddl>logs/cmstore_trig.log
grep -e "SQLSTATE" $CD/logs/cmstore_trig.log >/dev/null

if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE078
	EXITCODE=$CRREW4578E
	echo $CRREWECH023
	rcrdone
fi

rcrdone


